@@ -40,18 +40,6 @@
  * Largely based on Michael Fulbright's work on Anaconda.
  */
 
-/* To compile a test program, do:
- * $ gcc -DSYSTZ_GET_TEST -Wall -g -O0 -o system-timezone-get `pkg-config --cflags --libs glib-2.0 gobject-2.0 gio-2.0` system-timezone.c
- * or:
- * $ gcc -DSYSTZ_SET_TEST -Wall -g -O0 -o system-timezone-set `pkg-config --cflags --libs glib-2.0 gobject-2.0 gio-2.0` system-timezone.c
- *
- * You can then read the system timezone with:
- * $ system-timezone-get
- * and simulate a set of system timezone (in /tmp/etc/...) with:
- * $ system-timezone-set "Europe/Paris"
- */
-
-
 /* FIXME: it'd be nice to filter out the timezones that we might get when
  * parsing config files that are not in zone.tab. Note that it's also wrong
  * in some cases: eg, in tzdata2008b, Asia/Calcutta got renamed to
@@ -68,23 +56,12 @@
 
 /* Files that we look at and that should be monitored */
 #define CHECK_NB 5
-#ifndef SYSTZ_SET_TEST
 #define ETC_TIMEZONE        "/etc/timezone"
 #define ETC_TIMEZONE_MAJ    "/etc/TIMEZONE"
 #define ETC_RC_CONF         "/etc/rc.conf"
 #define ETC_SYSCONFIG_CLOCK "/etc/sysconfig/clock"
 #define ETC_CONF_D_CLOCK    "/etc/conf.d/clock"
 #define ETC_LOCALTIME       "/etc/localtime"
-#else
-/* Filenames that will be writable for testing */
-#define TEST_PREFIX         "/tmp/systz-test"
-#define ETC_TIMEZONE        TEST_PREFIX"/etc/timezone"
-#define ETC_TIMEZONE_MAJ    TEST_PREFIX"/etc/TIMEZONE"
-#define ETC_RC_CONF         TEST_PREFIX"/etc/rc.conf"
-#define ETC_SYSCONFIG_CLOCK TEST_PREFIX"/etc/sysconfig/clock"
-#define ETC_CONF_D_CLOCK    TEST_PREFIX"/etc/conf.d/clock"
-#define ETC_LOCALTIME       TEST_PREFIX"/etc/localtime"
-#endif /* SYSTZ_SET_TEST */
 
 /* The first 4 characters in a timezone file, from tzfile.h */
 #define TZ_MAGIC "TZif"
@@ -213,12 +190,27 @@ system_timezone_constructor (GType                  type,
         priv->env_tz = g_strdup (g_getenv ("TZ"));
 
         for (i = 0; i < CHECK_NB; i++) {
-                GFile *file;
+                GFile     *file;
+                GFile     *parent;
+                GFileType  parent_type;
 
                 file = g_file_new_for_path (files_to_check[i]);
-                priv->monitors[i] = g_file_monitor_file (file,
-                                                         G_FILE_MONITOR_NONE,
-                                                         NULL, NULL);
+
+                parent = g_file_get_parent (file);
+                parent_type = g_file_query_file_type (parent, G_FILE_QUERY_INFO_NONE, NULL);
+                g_object_unref (parent);
+
+                /* We don't try to monitor the file if the parent directory
+                 * doesn't exist: this means we're on a system where this file
+                 * is not useful to determine the system timezone.
+                 * Since gio does not monitor file in non-existing directories
+                 * in a clever way (as of gio 2.22, it just polls every other
+                 * seconds to see if the directory now exists), this avoids
+                 * unnecessary wakeups. */
+                if (parent_type == G_FILE_TYPE_DIRECTORY)
+                        priv->monitors[i] = g_file_monitor_file (file,
+                                                                 G_FILE_MONITOR_NONE,
+                                                                 NULL, NULL);
                 g_object_unref (file);
 
                 if (priv->monitors[i])
@@ -250,7 +242,8 @@ system_timezone_finalize (GObject *obj)
         }
 
         for (i = 0; i < CHECK_NB; i++) {
-                g_object_unref (priv->monitors[i]);
+                if (priv->monitors[i])
+                        g_object_unref (priv->monitors[i]);
                 priv->monitors[i] = NULL;
         }
 
@@ -1053,56 +1046,3 @@ system_timezone_error_quark (void)
 
         return ret;
 }
-
-#ifdef SYSTZ_GET_TEST
-int
-main (int    argc,
-      char **argv)
-{
-        char *tz;
-
-        tz = system_timezone_find ();
-        g_print ("%s\n", tz);
-        g_free (tz);
-
-        return 0;
-}
-#endif /* SYSTZ_GET_TEST */
-
-#ifdef SYSTZ_SET_TEST
-int
-main (int    argc,
-      char **argv)
-{
-        GError *error;
-        char   *dirname;
-
-        if (argc != 2) {
-                g_print ("Usage: %s TIMEZONE\n", argv[0]);
-                return 1;
-        }
-
-        dirname = g_path_get_dirname (ETC_TIMEZONE);
-        g_mkdir_with_parents (dirname, 0755);
-        g_free (dirname);
-        dirname = g_path_get_dirname (ETC_SYSCONFIG_CLOCK);
-        g_mkdir_with_parents (dirname, 0755);
-        g_free (dirname);
-        dirname = g_path_get_dirname (ETC_CONF_D_CLOCK);
-        g_mkdir_with_parents (dirname, 0755);
-        g_free (dirname);
-
-        error = NULL;
-        if (!system_timezone_set (argv[1], &error)) {
-                g_print ("%s\n", error->message);
-                g_error_free (error);
-                return 1;
-        }
-
-        g_print (TEST_PREFIX" is the test directory where files "
-                 "were written (feel free to populate this directory with "
-                 "files that should be modified by this program).\n");
-
-        return 0;
-}
-#endif /* SYSTZ_SET_TEST */
