@@ -27,12 +27,9 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkdnd.h>
+#include <glib/gi18n.h>
+
+#include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
 #include <libwnck/screen.h>
@@ -42,7 +39,8 @@
 
 #include <string.h>
 
-#define TIMEOUT_ACTIVATE 1000
+#define TIMEOUT_ACTIVATE_SECONDS 1
+#define SHOW_DESKTOP_ICON "user-desktop"
 
 
 typedef struct {
@@ -176,11 +174,11 @@ update_icon (ShowDesktopData *sdd)
 
 	error = NULL;
 	icon = gtk_icon_theme_load_icon (sdd->icon_theme,
-					 "user-desktop",
+					 SHOW_DESKTOP_ICON,
 					 icon_size, 0, &error);
 
 	if (icon == NULL) {
-		g_printerr (_("Failed to load %s: %s\n"), "user-desktop",
+		g_printerr (_("Failed to load %s: %s\n"), SHOW_DESKTOP_ICON,
 			    error ? error->message : _("Icon not found"));
 		if (error) {
 			g_error_free (error);
@@ -350,9 +348,9 @@ button_drag_motion (GtkWidget          *widget,
 {
 
 	if (sdd->button_activate == 0)
-		sdd->button_activate = g_timeout_add (TIMEOUT_ACTIVATE,
-						      button_motion_timeout,
-						      sdd);
+		sdd->button_activate = g_timeout_add_seconds (TIMEOUT_ACTIVATE_SECONDS,
+							      button_motion_timeout,
+							      sdd);
 	gdk_drag_status (context, 0, time);
 	
 	return TRUE;
@@ -508,11 +506,11 @@ show_desktop_applet_fill (PanelApplet *applet)
 
 static void
 display_help_dialog (BonoboUIComponent *uic,
-                     ShowDesktopData         *sdd,
+                     ShowDesktopData   *sdd,
                      const gchar       *verbname)
 {
 	wncklet_display_help (sdd->applet, "user-guide",
-			      "user-guide.xml", "gospanel-564");
+			      "gospanel-564", SHOW_DESKTOP_ICON);
 }
 
 static void
@@ -539,7 +537,7 @@ display_about_dialog (BonoboUIComponent *uic,
 			       authors,
 			       documenters,
 			       translator_credits,
-			       "user-desktop",
+			       SHOW_DESKTOP_ICON,
 			       "show-desktop",
 			       "show-desktop");
 }
@@ -564,7 +562,7 @@ button_toggled_callback (GtkWidget       *button,
                 dialog = gtk_message_dialog_new (NULL,
                                                  GTK_DIALOG_MODAL,
                                                  GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_OK,
+                                                 GTK_BUTTONS_CLOSE,
                                                  _("Your window manager does not support the show desktop button, or you are not running a window manager."));
 
                 g_object_add_weak_pointer (G_OBJECT (dialog),
