@@ -1831,7 +1831,7 @@ panel_profile_load_and_show_toplevel (GConfClient       *client,
 	}
 
 	if (!loading_queued_applets)
-		panel_applet_load_queued_applets ();
+		panel_applet_load_queued_applets (FALSE);
 }
 
 static void
@@ -2241,7 +2241,7 @@ panel_profile_object_id_list_update (GConfClient       *client,
 	g_slist_free (sublist);
 	g_slist_free (object_ids);
 
-	panel_applet_load_queued_applets ();
+	panel_applet_load_queued_applets (FALSE);
 }
 
 static void
@@ -2514,12 +2514,12 @@ panel_profile_load (void)
 
 	client  = panel_gconf_get_client ();
 
+	gconf_client_add_dir (client, PANEL_CONFIG_DIR "/general", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+
 	panel_compatibility_maybe_copy_old_config (client);
 
 	panel_compatibility_migrate_panel_id_list (client);
 
-	gconf_client_add_dir (client, PANEL_CONFIG_DIR "/general", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-
 	panel_profile_load_list (client,
 				 PANEL_CONFIG_DIR,
 				 PANEL_GCONF_TOPLEVELS,
@@ -2538,7 +2538,7 @@ panel_profile_load (void)
 
 	panel_profile_ensure_toplevel_per_screen (client, PANEL_CONFIG_DIR);
 
-	panel_applet_load_queued_applets ();
+	panel_applet_load_queued_applets (TRUE);
 }
 
 static gboolean
